==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Web/Gui/Resources/translations/Web_val-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="val-ES" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>Pàgina anterior</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>Vés a la pàgina anterior</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>Pàgina següent</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>Vés a la pàgina següent</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>Actualitza la pàgina web</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <source>Stop loading</source>
      <translation>Para la càrrega</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop the current loading</source>
      <translation>Para la càrrega actual</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <source>Zoom in</source>
      <translation>Apropa</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom into the page</source>
      <translation>Apropa a la pàgina</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Zoom out</source>
      <translation>Allunya</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out of the page</source>
      <translation>Allunya de la pàgina</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>Obri una pàgina web...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Obri una pàgina web en el FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>Form</name>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="14"/>
      <source>Sketchfab exporter</source>
      <translation>Exportador Sketchfab</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="39"/>
      <source>What to upload?</source>
      <translation>Què voleu pujar?</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="46"/>
      <source>Selection</source>
      <translation>Selecció</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="56"/>
      <source>All visible objects</source>
      <translation>Tots els objectes visibles</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="81"/>
      <source>Model name</source>
      <translation>Nom del model</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="88"/>
      <source>Private</source>
      <translation>Privat</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="100"/>
      <source>Description</source>
      <translation>Descripció</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="110"/>
      <source>Tags (separated by commas)</source>
      <translation>Etiquetes (separades per comes)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="119"/>
      <source>FreeCAD,</source>
      <translation type="unfinished">FreeCAD,</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="135"/>
      <source>Format</source>
      <translation>Format</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="143"/>
      <source>OBJ + MTL (Arch exporter)</source>
      <translation>OBJ + MTL (exportador d'arquitectura)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="148"/>
      <source>OBJ (standard Mesh exporter)</source>
      <translation>OBJ (exportador estàndard de malla)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="153"/>
      <source>DAE (Collada)</source>
      <translation>DAE (Collada)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="158"/>
      <source>STL</source>
      <translation>STL</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="163"/>
      <source>IGES (shapes only)</source>
      <translation>IGES (només formes)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="168"/>
      <source>IV</source>
      <translation>IV</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="176"/>
      <source>Sketchfab API token</source>
      <translation>Testimoni Sketchfab API</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="192"/>
      <source>Obtain</source>
      <translation>Obtín</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="201"/>
      <source>Upload</source>
      <translation>Puja</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="211"/>
      <source>uploading</source>
      <translation>pujada</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="218"/>
      <source>Success! View uploaded online</source>
      <translation>Correcte. La vista s'ha carregat en línia</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="80"/>
      <location filename="../../BrowserView.cpp" line="412"/>
      <source>Browser</source>
      <translation>Navegador</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="309"/>
      <source>File does not exist!</source>
      <translation>El fitxer no existeix.</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="304"/>
      <source>Error</source>
      <translation>Error</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="383"/>
      <source>Loading %1...</source>
      <translation>S'està carregant 1%...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="181"/>
      <source>Open in External Browser</source>
      <translation>Obri en un navegador extern</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="185"/>
      <source>Open in new window</source>
      <translation>Obri en una finestra nova</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>Navegació</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Web/Gui/Resources/translations/Web_val-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="val-ES" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>Pàgina anterior</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>Vés a la pàgina anterior</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>Pàgina següent</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>Vés a la pàgina següent</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>Actualitza la pàgina web</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <source>Stop loading</source>
      <translation>Para la càrrega</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop the current loading</source>
      <translation>Para la càrrega actual</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <source>Zoom in</source>
      <translation>Apropa</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom into the page</source>
      <translation>Apropa a la pàgina</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Zoom out</source>
      <translation>Allunya</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out of the page</source>
      <translation>Allunya de la pàgina</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>Obri una pàgina web...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Obri una pàgina web en el FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>Form</name>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="14"/>
      <source>Sketchfab exporter</source>
      <translation>Exportador Sketchfab</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="39"/>
      <source>What to upload?</source>
      <translation>Què voleu pujar?</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="46"/>
      <source>Selection</source>
      <translation>Selecció</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="56"/>
      <source>All visible objects</source>
      <translation>Tots els objectes visibles</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="81"/>
      <source>Model name</source>
      <translation>Nom del model</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="88"/>
      <source>Private</source>
      <translation>Privat</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="100"/>
      <source>Description</source>
      <translation>Descripció</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="110"/>
      <source>Tags (separated by commas)</source>
      <translation>Etiquetes (separades per comes)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="119"/>
      <source>FreeCAD,</source>
      <translation>FreeCAD,</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="135"/>
      <source>Format</source>
      <translation>Format</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="143"/>
      <source>OBJ + MTL (Arch exporter)</source>
      <translation>OBJ + MTL (exportador d'arquitectura)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="148"/>
      <source>OBJ (standard Mesh exporter)</source>
      <translation>OBJ (exportador estàndard de malla)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="153"/>
      <source>DAE (Collada)</source>
      <translation>DAE (Collada)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="158"/>
      <source>STL</source>
      <translation>STL</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="163"/>
      <source>IGES (shapes only)</source>
      <translation>IGES (només formes)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="168"/>
      <source>IV</source>
      <translation>IV</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="176"/>
      <source>Sketchfab API token</source>
      <translation>Testimoni Sketchfab API</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="192"/>
      <source>Obtain</source>
      <translation>Obtín</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="201"/>
      <source>Upload</source>
      <translation>Puja</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="211"/>
      <source>uploading</source>
      <translation>pujada</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="218"/>
      <source>Success! View uploaded online</source>
      <translation>Correcte. La vista s'ha carregat en línia</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="80"/>
      <location filename="../../BrowserView.cpp" line="440"/>
      <source>Browser</source>
      <translation>Navegador</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="337"/>
      <source>File does not exist!</source>
      <translation>El fitxer no existeix.</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="329"/>
      <location filename="../../BrowserView.cpp" line="333"/>
      <source>Error</source>
      <translation>Error</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="333"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>Hi hagué errors quan es carregava el fitxer. Algunes dades s'han pogut modificar o no s'han recuperat. Busqueu en la vista d'informes per a obtindre informació més específica sobre els objectes implicats.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="411"/>
      <source>Loading %1...</source>
      <translation>S'està carregant 1%...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="185"/>
      <source>Open in External Browser</source>
      <translation>Obri en un navegador extern</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="189"/>
      <source>Open in new window</source>
      <translation>Obri en una finestra nova</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>Navegació</translation>
    </message>
  </context>
</TS>
